========
Examples
========

.. toctree::
  :maxdepth: 2

.. fancy_include:: simple_phase.py

.. fancy_include:: background_tilt.py

.. fancy_include:: background_offset.py

.. fancy_include:: background_mask.py

.. fancy_include:: background_poly2o.py

.. fancy_include:: background_mask_sphere.py

.. fancy_include:: hologram_cell.py

.. fancy_include:: hologram_filters.py
